@@ -11,6 +11,7 @@
 #' @inheritParams add_global_p.tbl_regression
 #' @author Esther Drill, Daniel D. Sjoberg
 #' @family tbl_summary tools
+#' @family tbl_svysummary tools
 #' @family tbl_regression tools
 #' @family tbl_uvregression tools
 #' @export
@@ -65,7 +66,8 @@ add_q <- function(x, method = "fdr", pvalue_fun = NULL, quiet = NULL) {
     get_theme_element("add_q-arg:pvalue_fun") %||%
     get_theme_element("pkgwide-fn:pvalue_fun") %||%
     # default from p-value formatting function
-    (filter(x$table_header, .data$column == "p.value") %>% pull(.data$fmt_fun) %>% pluck(1))
+    (filter(x$table_header, .data$column == "p.value") %>% pull(.data$fmt_fun) %>% pluck(1)) %>%
+    gts_mapper("add_q(pvalue_fun=)")
 
   # checking pvalue_fun are functions
   if (!is.function(pvalue_fun)) {
@@ -84,7 +86,8 @@ add_q <- function(x, method = "fdr", pvalue_fun = NULL, quiet = NULL) {
   # update table_header --------------------------------------------------------
   # footnote text
   footnote_text <-
-    add_q_method_lookup[add_q_method_lookup$method == method, ]$method_label
+    add_q_method_lookup[add_q_method_lookup$method == method, ]$method_label %>%
+    translate_text()
 
   x$table_header <-
     tibble(column = names(x$table_body)) %>%
@@ -99,7 +102,7 @@ add_q <- function(x, method = "fdr", pvalue_fun = NULL, quiet = NULL) {
     )
 
   # adding  column header
-  x <- modify_header_internal(x, q.value = "**q-value**")
+  x <- modify_header_internal(x, q.value = paste0("**", translate_text("q-value"), "**"))
 
   # return final object --------------------------------------------------------
   # adding call
