@@ -16,7 +16,8 @@
 #' Must be one of "none", "column", "row", or "cell". Default is "cell" when
 #' `{N}` or `{p}` is used in statistic.
 #' @param margin Indicates which margins to add to the table.
-#' Default is `c("row", "column")`
+#' Default is `c("row", "column")`. Use `margin  = NULL` to suppress both
+#' row and column margins.
 #' @param margin_text Text to display for margin totals. Default is `"Total"`
 #' @inheritParams tbl_summary
 #'
@@ -80,7 +81,8 @@ tbl_cross <- function(data,
   # matching arguments ---------------------------------------------------------
   missing <- match.arg(missing)
   percent <- match.arg(percent)
-  margin <- match.arg(margin, several.ok = TRUE)
+  if (!is.null(margin))
+    margin <- match.arg(margin, several.ok = TRUE)
 
   # if no col AND no row provided, default to first two columns of data --------
   if (is.null(row) && is.null(col)) {
