@@ -2,7 +2,7 @@
 # GTSUMMARY OBJECT. IF YOU'RE CREATING A GTSUMMARY-LIKE FUNCTION, YOU'LL
 # WANT TO GRAB A COPY OF THIS FILE AND PLACE IT IN YOUR PACKAGE.
 
-# LAST UPDATED: 2020-05-09
+# LAST UPDATED: 2020-07-30
 
 # table_header_fill_missing -----------------------------------------------------
 #' Function fills out table_header when there are missing columns
@@ -37,7 +37,8 @@ table_header_fill_missing <- function(table_header, table_body = NULL) {
 
   # align ----------------------------------------------------------------------
   if (!"align" %in% names(table_header)) {
-    table_header$align <- ifelse(table_header$column == "label", "left", "center")
+    table_header$align <-
+      ifelse(table_header$column %in% c("label", "groupname_col"), "left", "center")
   }
 
   # missing_emdash -------------------------------------------------------------
@@ -331,7 +332,8 @@ tidyselect_to_list <- function(.data, x, .meta_data = NULL,
                                    arg_name = arg_name,
                                    select_single = select_single)
 
-        rhs <- rlang::f_rhs(x) %>% rlang::eval_tidy(env = rlang::f_env(x))
+        # evaluate RHS of formula in the original formula environment
+        rhs <- eval_rhs(x)
 
         # converting rhs and lhs into a named list
         purrr::map(lhs, ~ list(rhs) %>% rlang::set_names(.x)) %>%
@@ -441,6 +443,11 @@ tidyselect_to_string <- function(...data..., ...meta_data... = NULL,
   result
 }
 
+# simple function to evaluate the RHS of a formula in the formula's environment
+eval_rhs <- function(x) {
+  rlang::f_rhs(x) %>% rlang::eval_tidy(env = rlang::f_env(x))
+}
+
 # select helpers environments --------------------------------------------------
 # setting environments
 data_env <- rlang::new_environment()
