@@ -12,7 +12,7 @@
 #' @author Daniel D. Sjoberg
 
 assign_class <- function(data, variable, classes_expected) {
-  # extracing the base R class
+  # extracting the base R class
   classes_return <-
     map(variable, ~class(data[[.x]]) %>% intersect(classes_expected))
   classes_return
@@ -241,7 +241,7 @@ assign_summary_type <- function(data, variable, class, summary_type, value) {
 #' @param data Data frame.
 #' @param variable Vector of column name.
 #' @param var_label list that includes specified variable labels,
-#' e.g. `var_label = list(age = "Age, yrs")`
+#' e.g. `var_label = list(age = "Age")`
 #' @return Vector variable labels.
 #' @keywords internal
 #' @noRd
@@ -268,26 +268,14 @@ assign_var_label <- function(data, variable, var_label) {
 #' @keywords internal
 #' @author Emily Zabor, Daniel D. Sjoberg
 
-# takes as the input a vector of variable and summary types
 continuous_digits_guess <- function(data,
                                     variable,
-                                    summary_type,
-                                    class,
-                                    digits = NULL) {
-  pmap(
-    list(variable, summary_type, class),
-    ~ continuous_digits_guess_one(data, ..1, ..2, ..3, digits)
-  )
-}
-
-# runs for a single var
-continuous_digits_guess_one <- function(data,
-                                        variable,
-                                        summary_type,
-                                        class,
-                                        digits = NULL) {
+                                    summary_type) {
   # if all values are NA, returning 0
-  if (nrow(data) == sum(is.na(data[[variable]]))) {
+  if (!is_survey(data) && nrow(data) == sum(is.na(data[[variable]]))) {
+    return(0)
+  }
+  if (is_survey(data) && length(data$variables[[variable]]) == sum(is.na(data$variables[[variable]]))) {
     return(0)
   }
 
@@ -296,19 +284,23 @@ continuous_digits_guess_one <- function(data,
     return(NA)
   }
 
-  # if the number of digits is specified for a variable, return specified number
-  if (!is.null(digits[[variable]])) {
-    return(digits[[variable]])
+  # if class is integer, then round everything to nearest integer
+  if (!is_survey(data) && inherits(data[[variable]], "integer")) {
+    return(0)
   }
-
-  # if class is integer, then round everythng to nearest integer
-  if (class == "integer") {
+  if (is_survey(data) && inherits(data$variables[[variable]], "integer")) {
     return(0)
   }
 
   # calculate the spread of the variable
-  var_spread <- stats::quantile(data[[variable]], probs = c(0.95), na.rm = TRUE) -
+  if (!is_survey(data))
+    var_spread <-
+      stats::quantile(data[[variable]], probs = c(0.95), na.rm = TRUE) -
     stats::quantile(data[[variable]], probs = c(0.05), na.rm = TRUE)
+  if (is_survey(data))
+    var_spread <-
+      compute_survey_stat(data = data, variable = variable, by = NULL, f = "p95")$p95 -
+      compute_survey_stat(data = data, variable = variable, by = NULL, f = "p5")$p5
 
   # otherwise guess the number of dignits to use based on the spread
   case_when(
@@ -337,23 +329,42 @@ continuous_digits_guess_one <- function(data,
 df_by <- function(data, by) {
   if (is.null(by)) return(NULL)
 
-  if (inherits(data[[by]], "factor"))
-    result <- tibble(by = attr(data[[by]], "levels") %>%
-                       factor(x = ., levels= ., labels = .))
-  else result <- data %>% select(by) %>% dplyr::distinct() %>% set_names("by")
+  if (!is_survey(data)) {
+    # classic data.frame
+    if (inherits(data[[by]], "factor"))
+      result <- tibble(by = attr(data[[by]], "levels") %>%
+                         factor(x = ., levels= ., labels = .))
+    else result <- data %>% select(by) %>% dplyr::distinct() %>% set_names("by")
 
-  result <-
-    result %>%
-    arrange(!!sym("by")) %>%
-    mutate(
-      n = purrr::map_int(.data$by, ~ sum(data[[!!by]] == .x)),
-      N = sum(.data$n),
-      p = .data$n / .data$N,
-      by_id = 1:n(), # 'by' variable ID
-      by_chr = as.character(.data$by), # Character version of 'by' variable
-      by_col = paste0("stat_", .data$by_id) # Column name of in fmt_table1 output
-    ) %>%
-    select(starts_with("by"), everything())
+    result <-
+      result %>%
+      arrange(!!sym("by")) %>%
+      mutate(
+        n = purrr::map_int(.data$by, ~ sum(data[[!!by]] == .x)),
+        N = sum(.data$n),
+        p = .data$n / .data$N,
+        by_id = 1:n(), # 'by' variable ID
+        by_chr = as.character(.data$by), # Character version of 'by' variable
+        by_col = paste0("stat_", .data$by_id) # Column name of in fmt_table1 output
+      ) %>%
+      select(starts_with("by"), everything())
+
+  } else {
+    # survey object
+    svy_table <- survey::svytable(c_form(right = by), data, round = TRUE) %>%
+      as_tibble() %>%
+      set_names("by", "n") %>%
+      mutate(
+        N = sum(.data$n),
+        p = .data$n / .data$N
+      )
+
+    result <- df_by(data$variables, by) %>%
+      rename(n_unweighted = .data$n, N_unweighted = .data$N, p_unweighted = .data$p) %>%
+      left_join(svy_table, by = "by")
+
+    result
+  }
 
   attr(result$by, "label") <- NULL
   result
@@ -452,8 +463,8 @@ tbl_summary_input_checks <- function(data, by, label, type, value, statistic,
 
     # all sepcifed types are continuous, categorical, or dichotomous
     if (inherits(type, "formula")) type <- list(type)
-    if (!every(type, ~ eval(rlang::f_rhs(.x)) %in% c("continuous", "categorical", "dichotomous")) |
-        !every(type, ~ rlang::is_string(eval(rlang::f_rhs(.x))))) {
+    if (!every(type, ~ eval_rhs(.x) %in% c("continuous", "categorical", "dichotomous")) |
+        !every(type, ~ rlang::is_string(eval_rhs(.x)))) {
       stop(glue(
         "The RHS of the formula in the 'type'  argument must of one and only one of ",
         "\"continuous\", \"categorical\", or \"dichotomous\""
@@ -503,7 +514,7 @@ tbl_summary_input_checks <- function(data, by, label, type, value, statistic,
 
     # all sepcifed labels must be a string of length 1
     if (inherits(label, "formula")) label <- list(label)
-    if (!every(label, ~ rlang::is_string(eval(rlang::f_rhs(.x))))) {
+    if (!every(label, ~ rlang::is_string(eval_rhs(.x)))) {
       stop(glue(
         "The RHS of the formula in the 'label' argument must be a string."
       ), call. = FALSE)
@@ -533,9 +544,9 @@ tbl_summary_input_checks <- function(data, by, label, type, value, statistic,
       }
     }
 
-    # all sepcifed statistics must be a string of length 1
+    # all specified statistics must be a string of length 1
     if (inherits(statistic, "formula")) statistic <- list(statistic)
-    if (!every(statistic, ~ rlang::is_string(eval(rlang::f_rhs(.x))))) {
+    if (!every(statistic, ~ rlang::is_string(eval_rhs(.x)))) {
       stop(glue(
         "The RHS of the formula in the 'statistic' argument must be a string."
       ), call. = FALSE)
@@ -597,8 +608,8 @@ tbl_summary_input_checks <- function(data, by, label, type, value, statistic,
 
     # all sepcifed types are frequency or alphanumeric
     if (inherits(sort, "formula")) sort <- list(sort)
-    if (!every(sort, ~ eval(rlang::f_rhs(.x)) %in% c("frequency", "alphanumeric")) |
-        !every(sort, ~ rlang::is_string(eval(rlang::f_rhs(.x))))) {
+    if (!every(sort, ~ eval_rhs(.x) %in% c("frequency", "alphanumeric")) |
+        !every(sort, ~ rlang::is_string(eval_rhs(.x)))) {
       stop(glue(
         "The RHS of the formula in the 'sort' argument must of one and only one of ",
         "\"frequency\" or \"alphanumeric\""
@@ -652,9 +663,11 @@ tbl_summary_input_checks <- function(data, by, label, type, value, statistic,
 #   stat_display = NULL, digits = NULL, pvalue_fun = NULL
 # )
 
+
 # stat_label_match -------------------------------------------------------------
 # provide a vector of stat_display and get labels back i.e. {mean} ({sd}) gives Mean (SD)
 stat_label_match <- function(stat_display, iqr = TRUE) {
+  language <- get_theme_element("pkgwide-str:language", default = "en")
   labels <-
     tibble::tribble(
       ~stat, ~label,
@@ -674,7 +687,12 @@ stat_label_match <- function(stat_display, iqr = TRUE) {
       "{p_nonmiss}", "% not missing",
       "{N_miss}", "N missing",
       "{N_nonmiss}", "N",
-      "{N_obs}", "no. obs."
+      "{N_obs}", "no. obs.",
+      "{N_obs_unweighted}", "Total N (unweighted)",
+      "{N_miss_unweighted}", "N Missing (unweighted)",
+      "{N_nonmiss_unweighted}", "N not Missing (unweighted)",
+      "{p_miss_unweighted}", "% Missing (unweighted)",
+      "{p_nonmiss_unweighted}", "% not Missing (unweighted)"
     ) %>%
     # adding in quartiles
     bind_rows(
@@ -691,7 +709,8 @@ stat_label_match <- function(stat_display, iqr = TRUE) {
           str_remove_all(pattern = fixed("}")) %>%
           str_remove_all(pattern = fixed("{"))
       )
-    )
+    ) %>%
+    mutate(label = map_chr(.data$label, ~translate_text(.x, language)))
 
   # adding IQR replacements if indicated
   if (iqr == TRUE) {
@@ -699,8 +718,8 @@ stat_label_match <- function(stat_display, iqr = TRUE) {
       bind_rows(
         tibble::tribble(
           ~stat, ~label,
-          "{p25}, {p75}", "IQR",
-          "{p25} - {p75}", "IQR"
+          "{p25}, {p75}", translate_text("IQR", language),
+          "{p25} \U2013 {p75}", translate_text("IQR", language)
         ),
         labels
       )
@@ -734,19 +753,11 @@ footnote_stat_label <- function(meta_data) {
     distinct() %>%
     pull("message") %>%
     paste(collapse = "; ") %>%
-    paste0("Statistics presented: ", .)
+    paste0(translate_text("Statistics presented"), ": ", .)
 }
 
 # summarize_categorical --------------------------------------------------------
 summarize_categorical <- function(data, variable, by, class, dichotomous_value, sort, percent) {
-  # grabbing percent formatting function
-  percent_fun <-
-    get_theme_element("tbl_summary-fn:percent_fun") %||%
-    getOption("gtsummary.tbl_summary.percent_fun", default = style_percent)
-  N_fun <-
-    get_theme_element("tbl_summary-fn:N_fun",
-                      default = function(x) sprintf("%.0f", x))
-
   # stripping attributes/classes that cause issues -----------------------------
   # tidyr::complete throws warning `has different attributes on LHS and RHS of join`
   # when variable has label.  So deleting it.
@@ -815,33 +826,34 @@ summarize_categorical <- function(data, variable, by, class, dichotomous_value,
       select(-.data$variable_levels)
   }
 
-  # adding percent_fun as attr to p column
-  attr(result$p, "fmt_fun") <- percent_fun
-  attr(result$N, "fmt_fun") <- N_fun
-  attr(result$n, "fmt_fun") <- N_fun
-
   result
 }
 
 # summarize_continuous ---------------------------------------------------------
-summarize_continuous <- function(data, variable, by, stat_display, digits) {
+summarize_continuous <- function(data, variable, by, stat_display) {
   # stripping attributes/classes that cause issues -----------------------------
   # tidyr::complete throws warning `has different attributes on LHS and RHS of join`
   # when variable has label.  So deleting it.
   attr(data[[variable]], "label") <- NULL
   if (!is.null(by)) attr(data[[by]], "label") <- NULL
-  # same thing when the class "labelled" is included when labeled with the Hmisc package
+  # same thing when the class "labelled" is included when labelled with the Hmisc package
   class(data[[variable]]) <- setdiff(class(data[[variable]]), "labelled")
   if (!is.null(by)) class(data[[by]]) <- setdiff(class(data[[by]]), "labelled")
 
   # extracting function calls
-  fns_names_chr <-
-    str_extract_all(stat_display, "\\{.*?\\}") %>%
-    map(str_remove_all, pattern = fixed("}")) %>%
-    map(str_remove_all, pattern = fixed("{")) %>%
-    unlist() %>%
-    # removing elements protected as other items
-    setdiff(c("p_miss", "p_nonmiss", "N_miss", "N_nonmiss", "N_obs"))
+  fns_names_chr <- extracting_function_calls_from_stat_display(stat_display, variable)
+
+  # if there are no continuous summary functions, return tibble early ----------
+  if (length(fns_names_chr) == 0) {
+    if (!is.null(by)) {
+      df_stats <- tibble(
+        by = unique(data[[by]]) %>% sort(),
+        variable = variable
+      )
+    }
+    else df_stats <- tibble(variable = variable)
+    return(df_stats)
+  }
 
   # defining shortcut quantile functions, if needed
   if (any(fns_names_chr %in% paste0("p", 0:100))) {
@@ -854,17 +866,6 @@ summarize_continuous <- function(data, variable, by, stat_display, digits) {
       list2env(envir = rlang::env_parent())
   }
 
-  if (length(fns_names_chr) == 0) stop(glue(
-    "No summary function found in `{stat_display}` for variable '{variable}'.\n",
-    "Did you wrap the function name in curly brackets?"
-  ), call. = FALSE)
-
-  if (any(c("by", "variable") %in% fns_names_chr)) {
-    stop(paste(
-      "'by' and 'variable' are protected names, and continuous variables",
-      "cannot be summarized with functions by the these name."), call. = FALSE)
-  }
-
   # prepping data set
   variable_by_chr <- c("variable", switch(!is.null(by), "by"))
   df_by <- df_by(data, by)
@@ -910,27 +911,117 @@ summarize_continuous <- function(data, variable, by, stat_display, digits) {
       tidyr::pivot_wider(id_cols = c("variable"), names_from = "fn")
   }
 
-  # adding formatting function as attr to summary statistics columns
-  fmt_fun <- as.list(rep(digits, length.out = length(fns_names_chr))) %>%
-    set_names(fns_names_chr)
+  # returning final object
+  df_stats
+}
 
+# extracting_function_calls_from_stat_display ---------------------
+extracting_function_calls_from_stat_display <- function(stat_display, variable) {
+  fns_names_chr <- str_extract_all(stat_display, "\\{.*?\\}") %>%
+    map(str_remove_all, pattern = fixed("}")) %>%
+    map(str_remove_all, pattern = fixed("{")) %>%
+    unlist()
+
+  if (length(fns_names_chr) == 0) stop(glue(
+    "No summary function found in `{stat_display}` for variable '{variable}'.\n",
+    "Did you wrap the function name in curly brackets?"
+  ), call. = FALSE)
+
+  # removing elements protected as other items
+  fns_names_chr <- fns_names_chr %>%
+    setdiff(c("p_miss", "p_nonmiss", "N_miss", "N_nonmiss", "N_obs"))
+
+  if (any(c("by", "variable") %in% fns_names_chr)) {
+    stop(paste(
+      "'by' and 'variable' are protected names, and continuous variables",
+      "cannot be summarized with functions by the these name."), call. = FALSE)
+  }
+
+  fns_names_chr
+}
+
+# adding_formatting_as_attr ----------------------------------------------------
+adding_formatting_as_attr <- function(df_stats, data, variable, summary_type,
+                                      stat_display, digits) {
+  # setting the default formatting ---------------------------------------------
+  percent_fun <- get_theme_element("tbl_summary-fn:percent_fun") %||%
+    getOption("gtsummary.tbl_summary.percent_fun", default = style_percent)
+  N_fun <- get_theme_element("tbl_summary-fn:N_fun", default = style_number)
+
+  # extracting statistics requested
+  fns_names_chr <-
+    str_extract_all(stat_display, "\\{.*?\\}") %>%
+    map(str_remove_all, pattern = fixed("}")) %>%
+    map(str_remove_all, pattern = fixed("{")) %>%
+    unlist()
+  base_stats <- c("p_miss", "p_nonmiss", "N_miss", "N_nonmiss", "N_obs",
+                  "N_obs_unweighted", "N_miss_unweighted", "N_nonmiss_unweighted",
+                  "p_miss_unweighted", "p_nonmiss_unweighted")
+
+  # if user supplied number of digits to round, use them
+  if (!is.null(digits[[variable]])) {
+    digits[[variable]] <-
+      # making the digits passed the same length as stat vector
+      rep(digits[[variable]], length.out = length(fns_names_chr)) %>%
+      as.list() %>%
+      rlang::set_names(fns_names_chr)
+  }
+  # if no digits supplied and variable is continuous, guess how to summarize
+  else if (summary_type == "continuous") {
+    digits[[variable]] <-
+      continuous_digits_guess(data = data,
+                              variable = variable,
+                              summary_type = summary_type) %>%
+      rep(length.out = length(fns_names_chr %>% setdiff(base_stats))) %>%
+      as.list() %>%
+      rlang::set_names(fns_names_chr %>% setdiff(base_stats))
+  }
+
+  # adding the formatting function as an attribute
   df_stats <- purrr::imap_dfc(
     df_stats,
     function(column, colname) {
-      if(is.null(fmt_fun[[colname]])) return(column)
-      fmt <- glue("%.{fmt_fun[[colname]]}f")
-      attr(column, "fmt_fun") <- purrr::partial(sprintf, fmt = !!fmt)
+      if (colname %in% c("variable", "by")) return(column)
+
+      # if number of digits was passed by user, round to the specified digits
+      if (!is.null(digits[[variable]][[colname]])) {
+        if (summary_type == "continuous" && colname %in% c("p_miss", "p_nonmiss",
+                                                           "p_miss_unweighted",
+                                                           "p_nonmiss_unweighted"))
+          attr(column, "fmt_fun") <-
+            purrr::partial(style_number, scale = 100,
+                           digits = !!digits[[variable]][[colname]])
+        else if (colname %in% c("p", "p_miss", "p_nonmiss",
+                                "p_miss_unweighted", "p_nonmiss_unweighted"))
+          attr(column, "fmt_fun") <-
+            purrr::partial(style_number, scale = 100,
+                           digits = !!digits[[variable]][[colname]])
+        else
+          attr(column, "fmt_fun") <-
+            purrr::partial(style_number, digits = !!digits[[variable]][[colname]])
+      }
+      # if digits not specified, use the default percent and integer formatting
+      else if (colname %in% c("p" ,"p_miss", "p_nonmiss")) {
+        attr(column, "fmt_fun") <- percent_fun
+      }
+      else {
+        attr(column, "fmt_fun") <- N_fun
+      }
+
       column
     }
   )
 
-  # returning final object
   df_stats
 }
 
 # df_stats_to_tbl --------------------------------------------------------------
 df_stats_to_tbl <- function(data, variable, summary_type, by, var_label, stat_display,
                             df_stats, missing, missing_text) {
+  if (is_survey(data))
+    calculate_missing_fun <- calculate_missing_row_survey
+  else
+    calculate_missing_fun <- calculate_missing_row
 
   # styling the statistics -----------------------------------------------------
   for (v in (names(df_stats) %>% setdiff(c("by", "variable", "variable_levels")))) {
@@ -1003,11 +1094,11 @@ df_stats_to_tbl <- function(data, variable, summary_type, by, var_label, stat_di
   }
 
   # add rows for missing -------------------------------------------------------
-  if (missing == "always" || (missing == "ifany" & sum(is.na(data[[variable]])) > 0)) {
+  if (missing == "always" || (missing == "ifany" & has_na(data, variable))) {
     result <-
       result %>%
       bind_rows(
-        calculate_missing_row(data = data, variable = variable,
+        calculate_missing_fun(data = data, variable = variable,
                               by = by, missing_text = missing_text)
       )
   }
@@ -1028,12 +1119,17 @@ calculate_missing_row <- function(data, variable, by, missing_text) {
       !!variable := is.na(.data[[variable]])
     )
 
+
   # passing the T/F variable through the functions to format as we do in
   # the tbl_summary output
   summarize_categorical(
     data = data, variable = variable, by = by, class = "logical",
     dichotomous_value = TRUE, sort = "alphanumeric", percent = "column"
   ) %>%
+    adding_formatting_as_attr(
+      data = data, variable = variable,
+      summary_type = "dichotomous", stat_display = "{n}", digits = NULL
+    ) %>%
     {df_stats_to_tbl(
       data = data, variable = variable, summary_type = "dichotomous", by = by,
       var_label = missing_text, stat_display = "{n}", df_stats = .,
@@ -1046,13 +1142,12 @@ calculate_missing_row <- function(data, variable, by, missing_text) {
 # this function creates df_stats in the tbl_summary meta data table
 # and includes the number of missing values
 df_stats_fun <- function(summary_type, variable, class, dichotomous_value, sort,
-                         stat_display, digits, data, by, percent) {
+                         stat_display, data, by, percent, digits) {
   # first table are the standard stats
   t1 <- switch(
     summary_type,
     "continuous" = summarize_continuous(data = data, variable = variable,
-                                        by = by, stat_display = stat_display,
-                                        digits = digits),
+                                        by = by, stat_display = stat_display),
     "categorical" = summarize_categorical(data = data, variable = variable,
                                           by = by, class = class,
                                           dichotomous_value = dichotomous_value,
@@ -1068,7 +1163,7 @@ df_stats_fun <- function(summary_type, variable, class, dichotomous_value, sort,
                               variable = variable,
                               by = by, class = "logical",
                               dichotomous_value = TRUE,
-                              sort = "alphanumeric", percent = percent) %>%
+                              sort = "alphanumeric", percent = "column") %>%
     rename(p_miss = .data$p, N_obs = .data$N, N_miss = .data$n) %>%
     mutate(N_nonmiss = .data$N_obs - .data$N_miss,
            p_nonmiss = 1 - .data$p_miss)
@@ -1077,9 +1172,31 @@ df_stats_fun <- function(summary_type, variable, class, dichotomous_value, sort,
   merge_vars <- switch(!is.null(by), c("by", "variable")) %||% "variable"
   return <- left_join(t1, t2, by = merge_vars)
 
-  # setting fmt_fun for percents and integers
-  attr(return$p_nonmiss, "fmt_fun") <- attr(return$p_miss, "fmt_fun")
-  attr(return$N_nonmiss, "fmt_fun") <- attr(return$N_miss, "fmt_fun")
+  # adding formatting function as attr to summary statistics columns
+  return <- adding_formatting_as_attr(
+    df_stats = return, data = data, variable = variable,
+    summary_type = summary_type, stat_display = stat_display, digits = digits
+  )
 
   return
 }
+
+# translation function ---------------------------------------------------------
+translate_text <- function(x, language = get_theme_element("pkgwide-str:language", default = "en")) {
+  if (language == "en") return(x)
+
+  # sub-setting on row of text to translate
+  df_text <- filter(df_translations, .data$en == x)
+
+  # if no rows selected OR translation is not provided return x, otherwise the translated text
+  ifelse(nrow(df_text) != 1 || is.na(df_text[[language]]), x, df_text[[language]])
+}
+
+# test if a variable has some NA -------------------------------------
+has_na <- function(data, variable) {
+  if (is_survey(data)) {
+    sum(is.na(data$variables[[variable]])) > 0
+  } else {
+    sum(is.na(data[[variable]])) > 0
+  }
+}
